import { reactive } from 'vue';
import { $t } from '@/plugins/i18n';
import type { FormRules } from 'element-plus';

// 表格列
export const columns: TableColumnList = [
	{ type: 'selection', align: 'left' },
	{ type: 'index', index: (index: number) => index + 1, label: '序号', width: 60 },
	// 债务ID
	{ label: $t('debtId'), prop: 'debtId' },
	// 债务金额
	{ label: $t('installmentNumber'), prop: 'installmentNumber' },
	// 每期应还金额
	{ label: $t('installmentAmount'), prop: 'installmentAmount' },
	// 还款截止日期
	{ label: $t('dueDate'), prop: 'dueDate' },
	// 已还金额
	{ label: $t('paidAmount'), prop: 'paidAmount' },
	// 还款状态
	{ label: $t('paymentStatus'), prop: 'paymentStatus' },
	{ label: $t('table.updateTime'), prop: 'updateTime', sortable: true, width: 160 },
	{ label: $t('table.createTime'), prop: 'createTime', sortable: true, width: 160 },
	{ label: $t('table.operation'), fixed: 'right', width: 210, slot: 'operation' },
];

// 添加规则
export const rules = reactive<FormRules>({
	// 债务ID
	debtId: [{ required: true, message: `${$t('input')}${$t('debtId')}`, trigger: 'blur' }],
	// 债务金额
	installmentNumber: [{ required: true, message: `${$t('input')}${$t('installmentNumber')}`, trigger: 'blur' }],
	// 每期应还金额
	installmentAmount: [{ required: true, message: `${$t('input')}${$t('installmentAmount')}`, trigger: 'blur' }],
	// 还款截止日期
	dueDate: [{ required: true, message: `${$t('input')}${$t('dueDate')}`, trigger: 'blur' }],
	// 已还金额
	paidAmount: [{ required: true, message: `${$t('input')}${$t('paidAmount')}`, trigger: 'blur' }],
	// 还款状态
	paymentStatus: [{ required: true, message: `${$t('input')}${$t('paymentStatus')}`, trigger: 'blur' }],
});
